==> lerna-8.1.8-x86_64-1cf.txz: install/doinst.sh <==
( cd usr/bin ; rm -rf lerna )
( cd usr/bin ; ln -sf ../lib64/node_modules/lerna/dist/cli.js lerna )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf JSONStream )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../JSONStream/bin.js JSONStream )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf arborist )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../@npmcli/arborist/bin/index.js arborist )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf color-support )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../color-support/bin.js color-support )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf conventional-changelog-writer )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../conventional-changelog-writer/cli.js conventional-changelog-writer )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf conventional-commits-parser )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../conventional-commits-parser/cli.js conventional-commits-parser )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf conventional-recommended-bump )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../conventional-recommended-bump/cli.js conventional-recommended-bump )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf cssesc )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../cssesc/bin/cssesc cssesc )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf ejs )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../ejs/bin/cli.js ejs )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf envinfo )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../envinfo/dist/cli.js envinfo )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf esparse )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../esprima/bin/esparse.js esparse )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf esvalidate )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../esprima/bin/esvalidate.js esvalidate )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf flat )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../flat/cli.js flat )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf get-pkg-repo )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../get-pkg-repo/src/cli.js get-pkg-repo )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf git-raw-commits )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../git-raw-commits/cli.js git-raw-commits )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf git-semver-tags )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../git-semver-tags/cli.js git-semver-tags )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf glob )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../glob/dist/esm/bin.mjs glob )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf handlebars )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../handlebars/bin/handlebars handlebars )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf import-local-fixture )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../import-local/fixtures/cli.js import-local-fixture )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf installed-package-contents )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../@npmcli/installed-package-contents/bin/index.js installed-package-contents )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf is-ci )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../is-ci/bin.js is-ci )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf is-docker )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../is-docker/cli.js is-docker )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf jake )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../jake/bin/cli.js jake )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf js-yaml )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../@zkochan/js-yaml/bin/js-yaml.js js-yaml )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf json5 )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../json5/lib/cli.js json5 )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf mkdirp )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../mkdirp/bin/cmd.js mkdirp )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf node-gyp )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../node-gyp/bin/node-gyp.js node-gyp )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf node-which )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../which/bin/which.js node-which )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf nopt )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../nopt/bin/nopt.js nopt )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf nx )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../nx/bin/nx.js nx )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf nx-cloud )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../nx/bin/nx-cloud.js nx-cloud )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf pacote )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../pacote/bin/index.js pacote )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf resolve )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../resolve/bin/resolve resolve )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf rimraf )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../rimraf/dist/cjs/src/bin.js rimraf )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf semver )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../semver/bin/semver.js semver )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf sl-log-transformer )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../strong-log-transformer/bin/sl-log-transformer.js sl-log-transformer )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf tao )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../@nrwl/tao/index.js tao )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf tsc )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../typescript/bin/tsc tsc )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf tsserver )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../typescript/bin/tsserver tsserver )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf uglifyjs )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../uglify-js/bin/uglifyjs uglifyjs )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf uuid )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../uuid/dist/bin/uuid uuid )
( cd usr/lib64/node_modules/lerna/node_modules/@yarnpkg/parsers/node_modules/.bin ; rm -rf js-yaml )
( cd usr/lib64/node_modules/lerna/node_modules/@yarnpkg/parsers/node_modules/.bin ; ln -sf ../js-yaml/bin/js-yaml.js js-yaml )
( cd usr/lib64/node_modules/lerna/node_modules/cross-spawn/node_modules/.bin ; rm -rf node-which )
( cd usr/lib64/node_modules/lerna/node_modules/cross-spawn/node_modules/.bin ; ln -sf ../which/bin/node-which node-which )
( cd usr/lib64/node_modules/lerna/node_modules/front-matter/node_modules/.bin ; rm -rf js-yaml )
( cd usr/lib64/node_modules/lerna/node_modules/front-matter/node_modules/.bin ; ln -sf ../js-yaml/bin/js-yaml.js js-yaml )
( cd usr/lib64/node_modules/lerna/node_modules/meow/node_modules/read-pkg/node_modules/.bin ; rm -rf semver )
( cd usr/lib64/node_modules/lerna/node_modules/meow/node_modules/read-pkg/node_modules/.bin ; ln -sf ../semver/bin/semver semver )
( cd usr/lib64/node_modules/lerna/node_modules/read-pkg/node_modules/.bin ; rm -rf semver )
( cd usr/lib64/node_modules/lerna/node_modules/read-pkg/node_modules/.bin ; ln -sf ../semver/bin/semver semver )
( cd usr/lib64/node_modules/lerna/node_modules/write-json-file/node_modules/.bin ; rm -rf semver )
( cd usr/lib64/node_modules/lerna/node_modules/write-json-file/node_modules/.bin ; ln -sf ../semver/bin/semver semver )
( cd usr/lib64/node_modules/root/node_modules/.bin ; rm -rf network-address )
( cd usr/lib64/node_modules/root/node_modules/.bin ; ln -sf ../network-address/cli.js network-address )

==> lerna-8.1.9-x86_64-2cf.txz: install/doinst.sh <==
( cd usr/bin ; rm -rf lerna )
( cd usr/bin ; ln -sf ../lib64/node_modules/lerna/dist/cli.js lerna )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf JSONStream )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../JSONStream/bin.js JSONStream )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf arborist )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../@npmcli/arborist/bin/index.js arborist )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf color-support )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../color-support/bin.js color-support )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf conventional-changelog-writer )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../conventional-changelog-writer/cli.js conventional-changelog-writer )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf conventional-commits-parser )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../conventional-commits-parser/cli.js conventional-commits-parser )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf conventional-recommended-bump )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../conventional-recommended-bump/cli.js conventional-recommended-bump )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf cssesc )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../cssesc/bin/cssesc cssesc )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf ejs )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../ejs/bin/cli.js ejs )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf envinfo )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../envinfo/dist/cli.js envinfo )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf esparse )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../esprima/bin/esparse.js esparse )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf esvalidate )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../esprima/bin/esvalidate.js esvalidate )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf flat )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../flat/cli.js flat )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf get-pkg-repo )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../get-pkg-repo/src/cli.js get-pkg-repo )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf git-raw-commits )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../git-raw-commits/cli.js git-raw-commits )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf git-semver-tags )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../git-semver-tags/cli.js git-semver-tags )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf glob )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../glob/dist/esm/bin.mjs glob )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf handlebars )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../handlebars/bin/handlebars handlebars )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf import-local-fixture )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../import-local/fixtures/cli.js import-local-fixture )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf installed-package-contents )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../@npmcli/installed-package-contents/bin/index.js installed-package-contents )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf is-ci )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../is-ci/bin.js is-ci )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf is-docker )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../is-docker/cli.js is-docker )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf jake )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../jake/bin/cli.js jake )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf js-yaml )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../@zkochan/js-yaml/bin/js-yaml.js js-yaml )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf json5 )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../json5/lib/cli.js json5 )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf mkdirp )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../mkdirp/bin/cmd.js mkdirp )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf node-gyp )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../node-gyp/bin/node-gyp.js node-gyp )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf node-which )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../which/bin/which.js node-which )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf nopt )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../nopt/bin/nopt.js nopt )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf nx )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../nx/bin/nx.js nx )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf nx-cloud )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../nx/bin/nx-cloud.js nx-cloud )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf pacote )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../pacote/bin/index.js pacote )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf resolve )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../resolve/bin/resolve resolve )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf rimraf )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../rimraf/dist/cjs/src/bin.js rimraf )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf semver )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../semver/bin/semver.js semver )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf sl-log-transformer )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../strong-log-transformer/bin/sl-log-transformer.js sl-log-transformer )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf tsc )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../typescript/bin/tsc tsc )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf tsserver )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../typescript/bin/tsserver tsserver )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf uglifyjs )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../uglify-js/bin/uglifyjs uglifyjs )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf uuid )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../uuid/dist/bin/uuid uuid )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; rm -rf yaml )
( cd usr/lib64/node_modules/lerna/node_modules/.bin ; ln -sf ../yaml/bin.mjs yaml )
( cd usr/lib64/node_modules/lerna/node_modules/@yarnpkg/parsers/node_modules/.bin ; rm -rf js-yaml )
( cd usr/lib64/node_modules/lerna/node_modules/@yarnpkg/parsers/node_modules/.bin ; ln -sf ../js-yaml/bin/js-yaml.js js-yaml )
( cd usr/lib64/node_modules/lerna/node_modules/cross-spawn/node_modules/.bin ; rm -rf node-which )
( cd usr/lib64/node_modules/lerna/node_modules/cross-spawn/node_modules/.bin ; ln -sf ../which/bin/node-which node-which )
( cd usr/lib64/node_modules/lerna/node_modules/front-matter/node_modules/.bin ; rm -rf js-yaml )
( cd usr/lib64/node_modules/lerna/node_modules/front-matter/node_modules/.bin ; ln -sf ../js-yaml/bin/js-yaml.js js-yaml )
( cd usr/lib64/node_modules/lerna/node_modules/meow/node_modules/read-pkg/node_modules/.bin ; rm -rf semver )
( cd usr/lib64/node_modules/lerna/node_modules/meow/node_modules/read-pkg/node_modules/.bin ; ln -sf ../semver/bin/semver semver )
( cd usr/lib64/node_modules/lerna/node_modules/read-pkg/node_modules/.bin ; rm -rf semver )
( cd usr/lib64/node_modules/lerna/node_modules/read-pkg/node_modules/.bin ; ln -sf ../semver/bin/semver semver )
( cd usr/lib64/node_modules/lerna/node_modules/write-json-file/node_modules/.bin ; rm -rf semver )
( cd usr/lib64/node_modules/lerna/node_modules/write-json-file/node_modules/.bin ; ln -sf ../semver/bin/semver semver )
( cd usr/lib64/node_modules/root/node_modules/.bin ; rm -rf network-address )
( cd usr/lib64/node_modules/root/node_modules/.bin ; ln -sf ../network-address/cli.js network-address )
